@@ -5,7 +5,7 @@ import traceback
 import time
 from enum import Enum
 from typing import Union
-from ..common import pf_common as pfc
+from pi3dpf_ns.pi3dpf_common import pf_common as pfc
 
 _log = logging.getLogger(__name__)
 
